==> jei-1.21.1-fabric-19.27.0.337-sources.jar: mezz/jei/fabric/input/FabricJeiKeyMappingBuilder.java <==
package mezz.jei.fabric.input;

import mezz.jei.common.input.keys.AbstractJeiKeyMappingBuilder;
import mezz.jei.common.input.keys.IJeiKeyMappingInternal;
import mezz.jei.common.input.keys.IJeiKeyMappingBuilder;
import mezz.jei.common.input.keys.JeiKeyConflictContext;
import mezz.jei.common.input.keys.JeiKeyModifier;
import net.minecraft.class_3675;

public class FabricJeiKeyMappingBuilder extends AbstractJeiKeyMappingBuilder {
	protected final String category;
	protected final String description;
	protected JeiKeyConflictContext context = JeiKeyConflictContext.UNIVERSAL;

	public FabricJeiKeyMappingBuilder(String category, String description) {
		this.category = category;
		this.description = description;
	}

	@Override
	public IJeiKeyMappingBuilder setContext(JeiKeyConflictContext context) {
		this.context = context;
		return this;
	}

	@Override
	public IJeiKeyMappingBuilder setModifier(JeiKeyModifier modifier) {
		return this;
	}

	@Override
	protected IJeiKeyMappingInternal buildMouse(int mouseButton) {
		FabricKeyMapping keyMapping = new FabricKeyMapping(
			description,
			class_3675.class_307.field_1672,
			mouseButton,
			category,
			context
		);
		return new FabricJeiKeyMapping(keyMapping, context);
	}

	@Override
	public IJeiKeyMappingInternal buildKeyboardKey(int key) {
		FabricKeyMapping keyMapping = new FabricKeyMapping(
			description,
			class_3675.class_307.field_1668,
			key,
			category,
			context
		);
		return new FabricJeiKeyMapping(keyMapping, context);
	}
}

==> jei-1.21.11-fabric-27.3.0.10-sources.jar: mezz/jei/fabric/input/FabricJeiKeyMappingBuilder.java <==
package mezz.jei.fabric.input;

import mezz.jei.common.input.keys.AbstractJeiKeyMappingBuilder;
import mezz.jei.common.input.keys.IJeiKeyMappingInternal;
import mezz.jei.common.input.keys.IJeiKeyMappingBuilder;
import mezz.jei.common.input.keys.JeiKeyConflictContext;
import mezz.jei.common.input.keys.JeiKeyModifier;
import net.minecraft.class_304;
import net.minecraft.class_3675;

public class FabricJeiKeyMappingBuilder extends AbstractJeiKeyMappingBuilder {
	protected final class_304.class_11900 category;
	protected final String description;
	protected JeiKeyConflictContext context = JeiKeyConflictContext.UNIVERSAL;

	public FabricJeiKeyMappingBuilder(class_304.class_11900 category, String description) {
		this.category = category;
		this.description = description;
	}

	@Override
	public IJeiKeyMappingBuilder setContext(JeiKeyConflictContext context) {
		this.context = context;
		return this;
	}

	@Override
	public IJeiKeyMappingBuilder setModifier(JeiKeyModifier modifier) {
		return this;
	}

	@Override
	protected IJeiKeyMappingInternal buildMouse(int mouseButton) {
		FabricKeyMapping keyMapping = new FabricKeyMapping(
			description,
			class_3675.class_307.field_1672,
			mouseButton,
			category,
			context
		);
		return new FabricJeiKeyMapping(keyMapping, context);
	}

	@Override
	public IJeiKeyMappingInternal buildKeyboardKey(int key) {
		FabricKeyMapping keyMapping = new FabricKeyMapping(
			description,
			class_3675.class_307.field_1668,
			key,
			category,
			context
		);
		return new FabricJeiKeyMapping(keyMapping, context);
	}
}
